@@ -1,5 +1,7 @@
 """
-Main interface for codepipeline service literal definitions.
+Type annotations for codepipeline service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/literals.html)
 
 Usage::
 
